function dendro(level,noms)
% DENDRO Dendrogrma plot for the result from hierarchical clustering.
%
%	Usage: dendro(level)
%

set(gca, 'xticklabel', []);
xticklabel = level(end).cluster{1};
data_n = length(level);
axis([1, data_n, 0, level(end).height]); 
xlabel('Data index');
ylabel('Distance');
title('Dendrogram');
for i=1:data_n,
	h = text(i, 0, noms(i));
%	h = text(i, 0, num2str(level(end).cluster{1}(i)));
	set(h, 'rot', 90, 'fontsize', 8, 'hori', 'right');
end

% Generate necessary information for plotting dendrogram
% cap_center is the leg position for future cluster
cap_center(xticklabel) = 1:data_n;
levelinfo(1).cap_center = cap_center; 
% cap_height is the height for each cap
levelinfo(1).cap_height = zeros(1, data_n);
for i = 2:data_n,
	m = level(i).merged(1);
	n = level(i).merged(2);
	% Find cap_center
	levelinfo(i).cap_center = levelinfo(i-1).cap_center;
	levelinfo(i).cap_center(m) = ...
		(levelinfo(i).cap_center(m)+levelinfo(i).cap_center(n))/2; 
	levelinfo(i).cap_center(n) = [];
	% Find cap_height
	levelinfo(i).cap_height = levelinfo(i-1).cap_height;
	levelinfo(i).cap_height(m) = level(i).height;
	levelinfo(i).cap_height(n) = [];
end

% Plot caps for the dendrogram
center = 1:data_n;	% center for each cluster
for i = 2:data_n,
	height = level(i).height;
	m = level(i).merged(1);
	n = level(i).merged(2);
	cluster1 = level(i-1).cluster{m};
	cluster2 = level(i-1).cluster{n};
	left_point = cluster1(end);
	right_point = cluster2(1);
	left = find(xticklabel==left_point);
	right = find(xticklabel==right_point);

	left_x = levelinfo(i-1).cap_center(m);
	left_y = levelinfo(i-1).cap_height(m);
	right_x = levelinfo(i-1).cap_center(n);
	right_y = levelinfo(i-1).cap_height(n);
	line([left_x left_x], [left_y, height]);
	line([right_x right_x], [right_y, height]);
	line([left_x right_x], [height, height]);
end

